@@ -282,11 +282,19 @@ class Time():
         self.time = time
         self.sleep = sleep
         self.now()
-        self.common_date_time_formats = datetime_utils.common_date_time_formats
         self.break_flag = 0
 
+        self.common_date_time_formats = datetime_utils.common_date_time_formats
+        self.datetime_utils = datetime_utils
+
     def set_timezone(self, my_timezone):
-        datetime_utils.LOCAL_TIMEZONE = my_timezone
+        self.datetime_utils.LOCAL_TIMEZONE = my_timezone
+
+    def set_default_time_format(self, default_time_format):
+        self.datetime_utils.DEFAULT_TIME_FORMAT = default_time_format
+
+    def set_default_decimal_places(self, default_decimal_places):
+        self.datetime_utils.DEFAULT_DECIMAL_PLACES = default_decimal_places
 
     def now(self, round_=3):  # return now time
         self.t1 = time()
@@ -300,9 +308,19 @@ class Time():
         return now_r
 
     def get_current_beijing_time_dt(self):
+        """
+        当前的北京时间(返回datetime格式)
+        """
         return datetime_utils.get_current_beijing_time_dt()
 
     def get_current_beijing_time_str(self, fmt: str = None, decimal_places: (int, None) = None):
+        """
+       得到当前的北京时间字符串
+
+       :param fmt: 时间格式, 如"%Y-%m-%d %H:%M:%S.%f"
+       :param decimal_places: 保留几位小数
+       :return: 当前的北京时间字符串
+       """
         return datetime_utils.get_current_beijing_time_str(fmt, decimal_places)
 
     def tqdm_sleep(self, desc='正在启动程序...', T=3, times=100, fresh=0):
